pub struct PatchFlowModeKey {
pub component: usize,
pub exps: (usize, usize),
}Expand description
Identity of one free-patch flow mode (for tests / diagnostics): which coordinate component the vector field moves and its monomial exponents.
Fields
component: usizeexps: (usize, usize)Trait Implementations
Sourceimpl Clone for PatchFlowModeKey
impl Clone for PatchFlowModeKey
Sourcefn clone(&self) -> PatchFlowModeKey
fn clone(&self) -> PatchFlowModeKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PatchFlowModeKey
Sourceimpl Debug for PatchFlowModeKey
impl Debug for PatchFlowModeKey
impl Eq for PatchFlowModeKey
Sourceimpl PartialEq for PatchFlowModeKey
impl PartialEq for PatchFlowModeKey
Sourcefn eq(&self, other: &PatchFlowModeKey) -> bool
fn eq(&self, other: &PatchFlowModeKey) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PatchFlowModeKey