pub struct TorusFlowModeKey {
pub component: usize,
pub freq: (i32, i32),
pub is_cos: bool,
}Expand description
Identity of one flow mode (for tests and diagnostics): which coordinate
component the vector field moves, its integer frequency vector, and its
phase (cos vs sin).
Fields
component: usizefreq: (i32, i32)is_cos: boolTrait Implementations
Sourceimpl Clone for TorusFlowModeKey
impl Clone for TorusFlowModeKey
Sourcefn clone(&self) -> TorusFlowModeKey
fn clone(&self) -> TorusFlowModeKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TorusFlowModeKey
Sourceimpl Debug for TorusFlowModeKey
impl Debug for TorusFlowModeKey
impl Eq for TorusFlowModeKey
Sourceimpl PartialEq for TorusFlowModeKey
impl PartialEq for TorusFlowModeKey
Sourcefn eq(&self, other: &TorusFlowModeKey) -> bool
fn eq(&self, other: &TorusFlowModeKey) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TorusFlowModeKey